<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Gestor de fitxers lleuger</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programació:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Gestor de fitxers PCManFM-Qt

Drets d&apos;autor (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

Aquest programa és programari lliure; podeu redistribuir-lo i/o modificar-lo
sota els termes de la Llicència Pública General GNU tal com ha estat
publicada per la Free Software Foundation; ja sigui la versió 2 de la Llicència
o bé (si ho preferiu) qualsevol altra versió posterior.

Aquest programa es distribueix amb l&apos;esperança que sigui útil, però SENSE
CAP GARANTIA; fins i tot sense la garantia implícita de COMERCIALITZACIÓ,
SATISFACCIÓ DE QUALITAT o ADEQUACIÓ A UN ÚS CONCRET. Per a més
detalls vegeu la Llicència pública general de GNU.

Hauríeu d&apos;haver rebut una còpia de la Llicència Pública General GNU
juntament amb Engrampa; en cas contrari, escriviu a la Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.</translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>Autors</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Un mitjà extraïble està inserit</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Un mitjà extraïble està inserit&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Tipus de mitjà:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>S&apos;està detectant...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Seleccioneu l&apos;acció que voleu realitzar:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>Canvi de nom massiu</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="47"/>
        <source># will be replaced by numbers starting with:</source>
        <translation>Se substiturà # amb nombres, començant per:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="80"/>
        <source>Pad numbers with zero if possible</source>
        <translation>Afegeix zeros als nombres si és possible</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="87"/>
        <source>Use localized numbers</source>
        <translation>Fer servir nombres localitzats</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Rename selected files to:</source>
        <translation>Canvia el nom dels fitxers seleccionats:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="40"/>
        <source>Name#</source>
        <translation>Nom#</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>Connexió a un servidor remot</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation>Inici de &amp;sessió anònim</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation>Inicia la sessió com a l&apos;&amp;usuari:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation>Especifiqueu la carpeta remota a connectar</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="72"/>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="79"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="86"/>
        <source>Path:</source>
        <translation>Camí:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="96"/>
        <source>Host:</source>
        <translation>Amfitrió:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>Crea un llançador</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation>Nom específic d&apos;aquest llançador.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>Descripció:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation>Breu descripció o nom genèric, com ara «Navegador web» o «Carpeta d&apos;usuari».

Podeu deixar-ho en blanc.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>Comentari:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation>Un breu comentari.

Podeu deixar-ho en blanc.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Command:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="112"/>
        <location filename="../desktopentrydialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="121"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="130"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation>Icona a mostrar en el gestor d&apos;arxius, els menús, etc.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="152"/>
        <location filename="../desktopentrydialog.ui" line="162"/>
        <source>Run in terminal?</source>
        <translation>Vols executar al terminal?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="155"/>
        <source>Terminal:</source>
        <translation>Terminal:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="165"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation>Defineix si el programa s&apos;ha d&apos;executar en una finestra del terminal.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="169"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="174"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="182"/>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="189"/>
        <source>Whether this is a link or executes a command.</source>
        <translation>Si el text és un enllaç o executa una ordre.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="193"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="198"/>
        <source>Link</source>
        <translation>Enllaç</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="206"/>
        <source>Categories:</source>
        <translation>Catergories:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="213"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation>Llista de categories, separades per punt i coma, en què aquesta entrada apareixerà en el menú principal de l&apos;entorn d&apos;escriptori (p. ex. si s&apos;ubica en ~/.local/share/applications).

Només és necessari si voleu fer servir el fitxer en el menú principal. Altrament podeu deixar-ho en blanc.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Carpeta de l&apos;escriptori:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Fitxer de la imatge</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Camí a la carpeta</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>Na&amp;vega</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Preferències de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>Fons</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>Mode de la imatge del fons:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>Fitxer de la imatge del fons:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>Seleccioneu el color del fons:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>Fitxer d&apos;imatge</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>Camí al fitxer de la imatge</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation>Na&amp;vega</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>Mida de la icona:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>Text de les etiquetes</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>Seleccioneu el color de l&apos;ombra:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>Seleccioneu la lletra:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>Seleccioneu el color del text:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>Espaiat</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>Minimum item margins:</source>
        <translation>Marges mínims de l&apos;ítem:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="189"/>
        <source>3 px by default.</source>
        <translation>3 px per defecte.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="176"/>
        <location filename="../desktop-preferences.ui" line="192"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="205"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="172"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>1 px per defecte.
També es reserva un espai per a 3 línies de text.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>Marges de l&apos;àrea de treball:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation>Per defecte, les carpetes de l&apos;escriptori s&apos;obriran a PCManFM-Qt
si es prem amb el botó esquerre del ratolí, encara que no sigui
el gestor de fitxers predeterminat.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation>Obre les carpetes d&apos;escriptori en el gestor de fitxers per defecte fent clic esquerre</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation>Fes que tots els elements s&apos;ajustin a les seves posicions</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>Fons de pantalla</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>Transforma la imatge basada en dades EXIF</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation>Fons de pantalla individual per a cada monitor</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation>Habilita la presentació de diapositives</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>Carpeta de la imatge del fons de pantalla:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Browse</source>
        <translation>Navega</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source> hour(s)</source>
        <translation> hor(a/es)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="515"/>
        <source>and</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="528"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation>Els intervals de menys de 5 min seran ignorats</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="531"/>
        <source>Interval:</source>
        <translation>Interval:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source> minute(s)</source>
        <translation> minut(s)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="564"/>
        <source>Wallpaper folder</source>
        <translation>Carpeta del fons d&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation>Aleatoritza la presentació de diapositives</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation>Dreceres visibles</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>Carpeta de l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>Avançat</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Dreceres ocultes</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>Drecera</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation>Enfocar visualització, netegeu la barra de filtres</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation>Ctrl+Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation>Activa subfinestra lateral</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation>Focus a l&apos;entrada de la ruta</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation>Ctrl+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>Pestanya següent</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Maj+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>Pestanya anterior</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+Número</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>Salta a la pestanya</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+Número</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation>Retrocés</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>Ves amunt</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>Diàleg de cerca</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Maj+Inser</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation>Enganxa a la barra de filtrat temporal</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation>Mou el fitxer en deixar anar</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation>Copia el fitxer en deixar anar</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation>Fes un enllaç simbòlic en deixar anar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Gestor de fitxers</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation>Fitxers &amp;recents</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="139"/>
        <source>&amp;Toolbars</source>
        <translation>&amp;Barres d&apos;eines</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="146"/>
        <source>Path &amp;Bar</source>
        <translation>&amp;Barra del camí</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="153"/>
        <source>&amp;Filtering</source>
        <translation>&amp;Filtratge</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="228"/>
        <source>&amp;Tools</source>
        <translation>&amp;Eines</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="287"/>
        <source>Go &amp;Up</source>
        <translation>Vés a&amp;munt</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="290"/>
        <source>Go Up</source>
        <translation>Vés amunt</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="293"/>
        <source>Alt+Up</source>
        <translation>Alt+Amunt</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="302"/>
        <source>&amp;Home</source>
        <translation>Carpeta de l&apos;&amp;usuari</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="305"/>
        <source>Alt+Home</source>
        <translation>Alt+Inici</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="314"/>
        <source>&amp;Reload</source>
        <translation>To&amp;rna a carregar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="317"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="326"/>
        <source>Go</source>
        <translation>Vés</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="335"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="344"/>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="353"/>
        <source>&amp;New Window</source>
        <translation>Finestra &amp;nova</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="356"/>
        <source>New Window</source>
        <translatorcomment>Finestra nova</translatorcomment>
        <translation>Finestra nova</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="359"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="367"/>
        <source>Show &amp;Hidden</source>
        <translation>Mostra els oc&amp;ults</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="370"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="379"/>
        <source>&amp;Computer</source>
        <translation>&amp;Ordinador</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="388"/>
        <source>&amp;Trash</source>
        <translation>&amp;Paperera</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="393"/>
        <source>&amp;Network</source>
        <translation>&amp;Xarxa</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="402"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Escriptori</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="411"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Afegeix als marcadors</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="416"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicacions</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="421"/>
        <source>Reload</source>
        <translation>Recarrega</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="429"/>
        <source>&amp;Icon View</source>
        <translation>Vista d&apos;&amp;icones</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="437"/>
        <source>&amp;Compact View</source>
        <translation>Vista &amp;compacta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="445"/>
        <source>&amp;Detailed List</source>
        <translation>Llista &amp;detallada</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="453"/>
        <source>&amp;Thumbnail View</source>
        <translation>Vis&amp;ta de miniatures</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="462"/>
        <source>Cu&amp;t</source>
        <translation>Re&amp;talla</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="465"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="474"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="477"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="486"/>
        <source>&amp;Paste</source>
        <translation>Engan&amp;xa</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="489"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="494"/>
        <source>Select &amp;All</source>
        <translation>Seleccion&amp;a-ho tot</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="497"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>De&amp;select All</source>
        <translation>De&amp;sselecciona-ho tot</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>Pr&amp;eferences</source>
        <translation>Pr&amp;eferències</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Ascendent</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Descending</source>
        <translation>&amp;Descendent</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="534"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Per nom del fitxer</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="542"/>
        <source>By &amp;Modification Time</source>
        <translation>Per &amp;data de modificació</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>By C&amp;reation Time</source>
        <translation>Per &amp;data de creació</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By Deletio&amp;n Time</source>
        <translation>Per data d&apos;e&amp;liminació</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By File &amp;Type</source>
        <translation>Per tipus de &amp;fitxer</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By &amp;Owner</source>
        <translation>Pel pr&amp;opietari</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By &amp;Group</source>
        <translation>Per &amp;grup</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>&amp;Folder First</source>
        <translation>Primer les &amp;carpetes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>&amp;Hidden Last</source>
        <translation>&amp;Oculta últim</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="879"/>
        <source>Shift+F2</source>
        <translation>Maj+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="963"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation>Conserva els paràmetres de manera recursiva des &amp;d&apos;aquí</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="968"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation>Ves a la font dels ajustaments heretats</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="973"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation>&amp;Elimina els ajustaments de les carpetes inexistents</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="981"/>
        <source>&amp;Clear</source>
        <translation>&amp;Esborra</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="651"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>&amp;Case Sensitive</source>
        <translation>Distin&amp;ció de majúscules i minúscules</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="708"/>
        <source>By File &amp;Size</source>
        <translation>Per &amp;la mida del fitxer</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="713"/>
        <source>&amp;Close Window</source>
        <translation>Tan&amp;ca la finestra</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="734"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation>Obre la pestanya a la instància &amp;root</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>&amp;Folder</source>
        <translation>&amp;Carpeta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="760"/>
        <source>&amp;Blank File</source>
        <translation>Fitxer en &amp;blanc</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="847"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation>Preserva els ajustaments per a &amp;aquesta carpeta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="884"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation>Mo&amp;stra/Enfoca la barra de filtratge</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Show Filter Bar</source>
        <translation>Mostra la barra de filtratge</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="890"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="898"/>
        <source>S&amp;plit View</source>
        <translation>Dividei&amp;x la vista</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="901"/>
        <source>Split View</source>
        <translation>Divideix la vista</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="909"/>
        <source>&amp;Copy Full Path</source>
        <translation>&amp;Copia el camí complet</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="923"/>
        <source>Show Thumb&amp;nails</source>
        <translation>Mostra les mi&amp;niatures</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="926"/>
        <source>Show Thumbnails</source>
        <translation>Mostra les miniatures</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="934"/>
        <source>S&amp;ide Pane</source>
        <translation>Subfinestra &amp;lateral</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="937"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="942"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Dreceres &amp;ocultes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="947"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation>Obre la pestanya en mode d&apos;&amp;administrador</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <location filename="../main-win.ui" line="955"/>
        <source>Create Launcher</source>
        <translation>Crea un llançador</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="782"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>&amp;Clear All Filters</source>
        <translation>&amp;Neteja tots els filtres</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="790"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Maj+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Close &amp;previous tabs</source>
        <translation>Tanca les &amp;pestanyes anteriors</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="808"/>
        <source>Close &amp;next tabs</source>
        <translation>Tanca les pestanyes següe&amp;nts</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="852"/>
        <source>Connect to &amp;Server</source>
        <translation>Connecta&apos;t al &amp;servidor</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="860"/>
        <source>&amp;Location</source>
        <translation>&amp;Ubicació</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="868"/>
        <source>&amp;Path Buttons</source>
        <translation>Botons del &amp;camí</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="873"/>
        <source>&amp;Bulk Rename</source>
        <translation>Can&amp;vi de nom massiu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <source>Bulk Rename</source>
        <translation>Canvi de nom massiu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="813"/>
        <source>Close &amp;other tabs</source>
        <translation>Tanca les altr&amp;es pestanyes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="779"/>
        <source>Permanent &amp;filter bar</source>
        <translation>Barra de &amp;filtratge permanent</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="821"/>
        <source>&amp;Menu bar</source>
        <translation>Barra del &amp;menú</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="824"/>
        <source>Menu bar</source>
        <translation>Barra de menús</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="836"/>
        <location filename="../main-win.ui" line="839"/>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="607"/>
        <source>New &amp;Tab</source>
        <translation>Pes&amp;tanya nova</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="160"/>
        <source>&amp;Customized View Settings</source>
        <translation>&amp;Configuració de la vista personalitzada</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="610"/>
        <source>New Tab</source>
        <translation>Pestanya nova</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="613"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="622"/>
        <source>Go &amp;Back</source>
        <translation>Vés enda&amp;rrere</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="625"/>
        <source>Go Back</source>
        <translation>Vés endarrere</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="628"/>
        <source>Alt+Left</source>
        <translation>Alt+Esquerra</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="637"/>
        <source>Go &amp;Forward</source>
        <translation>Vés enda&amp;vant</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="640"/>
        <source>Go Forward</source>
        <translation>Vés endavant</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="643"/>
        <source>Alt+Right</source>
        <translation>Alt+Dreta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="648"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Inverteix la selecció</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="660"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="663"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="668"/>
        <source>&amp;Rename</source>
        <translation>&amp;Reanomena</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="671"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>C&amp;lose Tab</source>
        <translation>Tanca &amp;la pestanya</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Propietats del fitxer</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="687"/>
        <source>Alt+Return</source>
        <translation>Alt+Retorn</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="692"/>
        <source>&amp;Folder Properties</source>
        <translation>Propietats de la c&amp;arpeta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="721"/>
        <source>Edit Bookmarks</source>
        <translation>Edita els marcadors</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="726"/>
        <source>Open &amp;Terminal</source>
        <translation>Obre el &amp;terminal</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="729"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="739"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Edita els marcadors</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="751"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="763"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="768"/>
        <source>&amp;Find Files</source>
        <translation>Troba &amp;fitxers</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="771"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation>C&amp;rea nou</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="98"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="105"/>
        <location filename="../main-win.ui" line="129"/>
        <source>&amp;View</source>
        <translation>&amp;Visualitza</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Ordenació</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="204"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marcadors</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="211"/>
        <source>&amp;Go</source>
        <translation>&amp;Vés</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="253"/>
        <source>Main Toolbar</source>
        <translation>Barra d&apos;eines principal</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Name of configuration profile</source>
        <translation>Nom del perfil de la configuració</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>PROFILE</source>
        <translation>PERFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation>Executa PCManFM-Qt com a dimoni</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="192"/>
        <source>Quit PCManFM-Qt</source>
        <translation>Sortir de PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="195"/>
        <source>Launch desktop manager</source>
        <translation>Llança el gestor d&apos;escriptoris</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="198"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Apaga el gestor d&apos;escriptoris si s&apos;està executant</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Obre el diàleg de preferències de l&apos;escriptori en la pàgina amb el nom especificat</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <location filename="../application.cpp" line="216"/>
        <source>NAME</source>
        <translation>NOM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <source>Open new window</source>
        <translation>Obre una finestra nova</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="207"/>
        <source>Open Find Files utility</source>
        <translation>Obre la utilitat Troba fitxers</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Estableix la imatge del fons de l&apos;escriptori a partir del FITXER de la imatge</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>FILE</source>
        <translation>FITXER</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>MODE</source>
        <translation>MODE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>Estableix el mode de la imatge del fons de l&apos;escriptori. MODE=(%1)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Obre el diàleg de preferències en la pàgina amb el nom especificat</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>Files or directories to open</source>
        <translation>Els fitxers o els directoris a obrir</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FITXER1, FITXER2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="648"/>
        <location filename="../application.cpp" line="653"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="653"/>
        <source>Terminal emulator is not set.</source>
        <translation>L&apos;emulador del terminal no està establert.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>Obre al gestor de fitxers</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="138"/>
        <source>Removable Disk</source>
        <translation>Disc extraïble</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation>SSH</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation>WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>WebDav segur</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation>HTTPS</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>L&apos;ordre a executar.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>La URL d&apos;accés.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>Seleccioneu una icona</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Imatges (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>Seleccioneu un fitxer executable</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>Seleccioneu un fitxer</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>Tan sols omple amb el color del fons</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Estira per omplir tota la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>Estira per omplir la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>Centra a la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Mosaic de la imatge per omplir tota la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>Fes zoom a la imatge per omplir tota la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="264"/>
        <source>Select Wallpaper</source>
        <translation>Selecciona un fons de pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="268"/>
        <source>Image Files</source>
        <translation>Fitxers d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="310"/>
        <source>Select Wallpaper Folder</source>
        <translation>Selecciona la carpeta del fons de pantalla</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="303"/>
        <source>Trash (One item)</source>
        <translation>Paperera (un element)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="306"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>Paperera (%Ln element)</numerusform>
            <numerusform>Paperera (%Ln elements)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="310"/>
        <source>Trash (Empty)</source>
        <translation>Paperera (buida)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="345"/>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="359"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="997"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1003"/>
        <location filename="../desktopwindow.cpp" line="1043"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>Fi&amp;xa a la posició actual</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1011"/>
        <source>Empty Trash</source>
        <translation>Buida la paperera</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1070"/>
        <source>Hide Desktop Items</source>
        <translation>Oculta els ítems de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1076"/>
        <source>Create Launcher</source>
        <translation>Crea un llançador</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1079"/>
        <source>Desktop Preferences</source>
        <translation>Preferències de l&apos;escriptori</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>Neteja el text (Ctrl+K o Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Root Instance</source>
        <translation>Instància de root</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="742"/>
        <source>Hide menu bar</source>
        <translation>Oculta la barra de menús</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>Això ocultarà completament la barra de menús, utilitzeu Ctrl+M per tornar-la a mostrar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1190"/>
        <source>Version: %1</source>
        <translation>Versió: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="2161"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mou a la paperera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="2161"/>
        <source>&amp;Delete</source>
        <translation>&amp;Suprimeix</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1997"/>
        <source>Customized View Settings</source>
        <translation>Configuració de la vista personalitzada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2268"/>
        <location filename="../mainwindow.cpp" line="2276"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2276"/>
        <source>Switch user command is not set.</source>
        <translation>L&apos;ordre de canvi d&apos;usuari no està establerta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2378"/>
        <source>Cleaning Folder Settings</source>
        <translation>Netejant la configuració de la carpeta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation>Voleu suprimir la configuració de carpetes inexistents? 
Pot ser útil si es tornen a crear aquestes carpetes.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="199"/>
        <source>Icon View</source>
        <translation>Vista d&apos;icones</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="200"/>
        <source>Compact View</source>
        <translation>Vista compacta</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="201"/>
        <source>Thumbnail View</source>
        <translation>Vista de miniatures</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="202"/>
        <source>Detailed List View</source>
        <translation>Vista de llista detallada</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="443"/>
        <source>Search Results</source>
        <translation>Resultats de la cerca</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="446"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="450"/>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="453"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="456"/>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="553"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Espai lliure: %1 (total: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="579"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n ítem</numerusform>
            <numerusform>%n ítems</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="581"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n ocult)</numerusform>
            <numerusform> (%n ocults)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="586"/>
        <location filename="../tabpage.cpp" line="789"/>
        <location filename="../tabpage.cpp" line="803"/>
        <source>Link to</source>
        <translation>enllaç a</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="815"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>%n ítem seleccionat</numerusform>
            <numerusform>%n ítems seleccionats</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>Molts fitxers</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Voleu obrir aquest %1 fitxer?</numerusform>
            <numerusform>Voleu obrir aquests %1 fitxers?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="122"/>
        <source>Open in New T&amp;ab</source>
        <translation>Obre en una pest&amp;anya nova</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="126"/>
        <source>Open in New Win&amp;dow</source>
        <translatorcomment>Obre en una fines&amp;tra nova</translatorcomment>
        <translation>Obre en una fines&amp;tra nova</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="134"/>
        <location filename="../view.cpp" line="152"/>
        <source>Open in Termina&amp;l</source>
        <translation>Obre al termina&amp;l</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Interfície d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Comportament</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Avançat</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation>Selecciona els fitxers creats recentment</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>Mida de les icones grans:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>Mida de les icones petites:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>Mida de les miniatures:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation>Mida de les icones del plafó lateral:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>Tema de les icones:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation>Mostra sempre la barra de les pestanyes</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Mostra els botons de &apos;Tanca&apos; en les pestanyes	</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation>Recorda la mida de l&apos;última finestra tancada</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation>Amplada predeterminada de les finestres noves:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation>Alçada predeterminada de les finestres noves:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Navegació</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation>Obre els fitxers amb un sol clic</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="113"/>
        <source>Default view mode:</source>
        <translation>Mode predeterminat de la vista:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source> sec</source>
        <translatorcomment> s</translatorcomment>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation>Operacions dels fitxers</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation>Confirmació abans d&apos;eliminar fitxers</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Mou els fitxers suprimits a la &quot;paperera&quot; en lloc d&apos;eliminar-los del disc.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation>Mostra les miniatures dels fitxers</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation>Mostra únicament les miniatures per als fitxers locals</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation>Si no està marcat, s&apos;utilitzarà la configuració de l&apos;entorn d&apos;escriptori.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="126"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation>Estableix a zero per desactivar la selecció automàtica.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation>Retard de la selecció automàtica en mode d&apos;un sol clic:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="147"/>
        <source>Open in current tab</source>
        <translation>Obre en la pestanya actual</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="152"/>
        <source>Open in new tab</source>
        <translation>Obre en una pestanya nova</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="157"/>
        <source>Open in new window</source>
        <translation>Obre en una finestra nova</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Elimina els fitxers en el mitjà extraïble en lloc de la creació de la &quot;paperera&quot;</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Confirmació abans de moure fitxers a la &quot;paperera&quot;</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation>Requereix reiniciar l&apos;aplicació perquè tingui efecte completament</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation>Inicia els fitxers executables sense preguntar-ho</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation>També se seleccionaran els fitxers reanomenats</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>Nombre de fitxers recents:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation>Utilitzat amb la vista d&apos;icones</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>Utilitzat amb la vista compacta i la vista de llista detallada</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation>Utilitzat amb la vista de miniatures</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>Interfície d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation>Tracta els fitxers de còpia de seguretat com a ocults</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Mostra ombrejades les icones dels fitxers ocults</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation>Marges mínims de l&apos;ítem a la vista d&apos;icones:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation>3 px per defecte.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>1 px per defecte.
També es reserva un espai per a 3 línies de text.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>Quan es desmarca, únicament es mostrarà la
barra de tasques si hi ha més d&apos;una pestanya.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>Canvia a la pestanya oberta recentment</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation>Torna a obrir les pestanyes de l&apos;última finestra en una finestra nova</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation>El generador integrat crea miniatures d&apos;imatges que són compatibles amb Qt.

Normalment, la majoria dels tipus d&apos;imatge són compatibles. El límit de mida per defecte és 4 MiB.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>Límit de mida de la imatge per al generador integrat de miniatures:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation>Si existeixen, s&apos;utilitzen miniatures externes per a vídeos, documents PDF, etc.

Un valor de -1 significa que no hi ha límit per a la mida del fitxer (per defecte).</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation>Mida del fitxer per a miniatures externes:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>Sense límit</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="853"/>
        <source>Examples:&lt;br&gt;For terminal: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;For switching user: &lt;i&gt;lxsudo %s&lt;/i&gt; or &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; is the command line you want to execute with terminal or su.&lt;br&gt; Important: Please use lxsudo, sudo alone will wreck permissions of the settings file.</source>
        <translation>Exemples:&lt;br&gt;Per a terminal: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;Per canviar d&apos;usuari: &lt;i&gt;lxsudo %s&lt;/i&gt; o &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; és la línia d&apos;ordres que heu d&apos;executar amb terminal o com super usuari. &lt;br&gt; Important: Si us plau useu lxsudo, només &quot;sudo&quot; destruirà els permisos del fitxer de configuració.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="919"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Maximum search history:</source>
        <translation>Límit de l&apos;historial de cerca:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="948"/>
        <source>Clear search history</source>
        <translation>Esborra l&apos;historial de cerques</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="983"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Es necessita reiniciar l&apos;aplicació perquè els canvis tinguin efecte.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="139"/>
        <source>Bookmarks menu:</source>
        <translation>Menú d&apos;adreces d&apos;interès:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="165"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation>Mostra el menú contextual de la carpeta amb Ctrl + clic dret</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation>Obre les carpetes en pestanyes noves en la mesura que sigui possible</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>Mode de finestra única</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation>Mostra sempre els noms dels fitxers reals</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation>No mostra la informació emergent del fitxer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>Necessita ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>Munta automàticament</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Munta automàticament els volums muntables amb la inicialització del programa</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Munta automàticament els mitjans extraïbles quan aquests són inserits</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Mostra les opcions disponibles per als mitjans extraïbles quan s&apos;insereixin</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation>Quan es desmunta un mitjà extraïble:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Tanca la pes&amp;tanya que conté el mitjà extraïble</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Can&amp;via la carpeta a la pestanya amb la carpeta de l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>Programes</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator:</source>
        <translation>Emulador de terminal:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="840"/>
        <source>Switch &amp;user command:</source>
        <translation>Ordre per al canvi d&apos;&amp;usuari:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="866"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>In&amp;tegració amb l&apos;arxivador:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="889"/>
        <source>Templates</source>
        <translation>Plantilles</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="895"/>
        <source>Show only user defined templates in menu</source>
        <translation>Mostra al menú únicament les plantilles definides de l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="902"/>
        <source>Show only one template for each MIME type</source>
        <translation>Mostra únicament una plantilla per a cadascun dels tipus MIME</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="909"/>
        <source>Run default application after creation from template</source>
        <translation>Executa l&apos;aplicació predeterminada després de la creació a partir de la plantilla</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Utilitza els prefixos decimals del SI en lloc dels prefixos binaris de l&apos;IEC</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Renaming files...</source>
        <translation>S&apos;està canviant el nom als fitxers...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Abort</source>
        <translation>Avorta</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Renaming is aborted.</source>
        <translation>S&apos;ha avortat el canvi de nom.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <location filename="../bulkrename.cpp" line="124"/>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <source>No file could be renamed.</source>
        <translation>No es pot canviar el nom de cap fitxer.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="124"/>
        <source>Some files could not be renamed.</source>
        <translation>No s&apos;ha pogut canviar el nom d&apos;alguns fitxers.</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Cannot open as Admin.</source>
        <translation>No es pot obrir com a administrador.</translation>
    </message>
</context>
</TS>
